@@ -29,9 +29,9 @@ extern void copyGP_R(void *, void *);
 extern void deletedKGP_R(void *);
 extern void deletedKGPsep_R(void *);
 extern void deleteGP_R(void *);
-extern void deleteGPs_R();
+extern void deleteGPs_R(void );
 extern void deleteGPsep_R(void *);
-extern void deleteGPseps_R();
+extern void deleteGPseps_R(void);
 extern void distance_R(void *, void *, void *, void *, void *, void *);
 extern void distance_symm_R(void *, void *, void *, void *);
 extern void dllikGP_nug_R(void *, void *, void *, void *);
